# Step 3: Evaluate AI-Related Risks
### On this page
  * [AI Risk Associated with Applications](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-evaluate-risks#ai-risk-associated-with-applications)
  * [AI Risk Associated with AI Agents](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-evaluate-risks#ai-risk-associated-with-ai-agents)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-evaluate-risks#best-practices)


Analyze AI risks associated with applications and AI agents.
Evaluating risks associated with AI technologies is an essential part of an organization’s risk management strategy. Include AI risk assessments in your regular risk management practices. Plan your risk management initiatives to identify areas where AI poses significant risks and address them accordingly.
